@@ -1,9 +1,12 @@
 import asyncio
+import hashlib
 import logging
 import platform
 from contextlib import suppress
 from http import HTTPStatus
 from json import JSONDecodeError
+from os.path import isfile
+from os.path import join
 from typing import Any
 from typing import Mapping
 from typing import Optional
@@ -18,6 +21,7 @@ from dipdup import __version__
 from dipdup.config import HTTPConfig
 from dipdup.exceptions import InvalidRequestError
 from dipdup.prometheus import Metrics
+from dipdup.utils import touch
 
 safe_exceptions = (
     aiohttp.ClientConnectionError,
@@ -115,7 +119,13 @@ class _HTTPGateway:
         return self.__session
 
     # TODO: Move to separate method to cover SignalR negotiations too
-    async def _retry_request(self, method: str, url: str, weight: int = 1, **kwargs):
+    async def _retry_request(
+        self,
+        method: str,
+        url: str,
+        weight: int = 1,
+        **kwargs,
+    ):
         """Retry a request in case of failure sleeping according to config"""
         attempt = 1
         retry_sleep = self._config.retry_sleep or 0
@@ -158,7 +168,13 @@ class _HTTPGateway:
                 multiplier = 1 if ratelimit_sleep else self._config.retry_multiplier or 1
                 retry_sleep *= multiplier
 
-    async def _request(self, method: str, url: str, weight: int = 1, **kwargs):
+    async def _request(
+        self,
+        method: str,
+        url: str,
+        weight: int = 1,
+        **kwargs,
+    ):
         """Wrapped aiohttp call with preconfigured headers and ratelimiting"""
         if not url.startswith(self._url):
             url = self._url + '/' + url.lstrip('/')
@@ -187,6 +203,31 @@ class _HTTPGateway:
                 return await response.json()
             return await response.read()
 
+    async def _replay_request(
+        self,
+        method: str,
+        url: str,
+        weight: int = 1,
+        **kwargs,
+    ):
+        request_hash = hashlib.sha256(
+            f'{self._url} {method} {url} {kwargs}'.encode(),
+        ).hexdigest()
+        if not self._config.replay_path:
+            raise RuntimeError('Replay path is not set')
+        replay_path = join(self._config.replay_path.rstrip('/'), request_hash)
+
+        if isfile(replay_path):
+            with open(replay_path, 'rb') as file:
+                return orjson.loads(file.read())
+        else:
+            response = await self._retry_request(method, url, weight, **kwargs)
+            if response:
+                touch(replay_path)
+                with open(replay_path, 'wb') as file:
+                    file.write(orjson.dumps(response))
+            return response
+
     async def request(
         self,
         method: str,
@@ -195,7 +236,10 @@ class _HTTPGateway:
         **kwargs,
     ) -> Any:
         """Performs an HTTP request."""
-        return await self._retry_request(method, url, weight, **kwargs)
+        if self._config.replay_path:
+            return await self._replay_request(method, url, weight, **kwargs)
+        else:
+            return await self._retry_request(method, url, weight, **kwargs)
 
     def set_user_agent(self, *args: str) -> None:
         """Add list of arguments to User-Agent header"""
